from typing import Iterable

import click

from gcs_cli.config import GCS_CLIENT_DATA_CONFIG_KEY, token_storage_adapter
from gcs_cli.helpers import do_link_auth_flow, requires_login
from gcs_cli.parsing import globus_command


@globus_command(
    "consent",
    short_help="Update your session with specific consents",
    disable_options=["format", "map_http_status", "explicit_host"],
)
@click.argument("SCOPES", nargs=-1, required=True)
@requires_login
def session_consent(scopes: Iterable[str]) -> None:
    """
    Update your current GCS CLI session by authenticating with a specific scope or set
    of scopes.
    """
    # load local client info to pass to login flow
    adapter = token_storage_adapter()
    gcs_client_data = adapter.read_config(GCS_CLIENT_DATA_CONFIG_KEY)
    assert gcs_client_data is not None

    gcs_client_id = gcs_client_data["client_id"]

    # do a login flow with the scope param
    do_link_auth_flow(gcs_client_id, session_params={"scope": " ".join(scopes)})

    click.echo("\nYou have successfully updated your session.\n")
