from typing import TYPE_CHECKING, Any, Dict, Tuple

if TYPE_CHECKING:
    import uuid

from gcs_cli.commands.storage_gateway._common import make_update_command
from gcs_cli.parsing import (
    box_options,
    globus_command,
    storage_gateway_create_and_update_params,
    storage_gateway_id_arg,
)
from gcs_cli.sdk_client.data import BoxStoragePolicies, StorageGatewayDocument
from gcs_cli.services.gcs import BOX_CONNECTOR_ID


@globus_command("box", short_help="Update a Box Storage Gateway")
@storage_gateway_id_arg
@storage_gateway_create_and_update_params(create=False)
@box_options
@make_update_command
def box_update(
    storage_gateway_id: "uuid.UUID", *, box_settings: Dict[str, Any], **kwargs: Any
) -> Tuple["uuid.UUID", StorageGatewayDocument]:
    """
    Update an existing Box Storage Gateway.
    Any options given will replace existing values in the storage gateway's definition.
    Any options not given will retain their existing values.
    """
    policies = None
    if box_settings:
        policies = BoxStoragePolicies(
            enterpriseID=box_settings["enterpriseID"],
            boxAppSettings=box_settings["boxAppSettings"],
        )

    return (
        storage_gateway_id,
        StorageGatewayDocument(
            connector_id=BOX_CONNECTOR_ID, policies=policies, **kwargs
        ),
    )
