import pwd
from typing import (
    ClassVar,
    List,
    TYPE_CHECKING,
    Type,
)

from .base import (
    Check,
    CheckInvoker,
    MissingPropertyCheck,
    ObjectIsNotNoneCheck,
    PropertyConstraintCheck,
)

if TYPE_CHECKING:
    from ..models.credential import Credential  # noqa: F401


class CredentialCheck(CheckInvoker):
    checkers: ClassVar[List[Type[Check["Credential"]]]] = []
    object_name = "credential"


@CredentialCheck.checker
class UC01(ObjectIsNotNoneCheck["Credential"]):
    ...


@CredentialCheck.property_checker(property_name="username")
class UC02(MissingPropertyCheck["Credential"]):
    ...


@CredentialCheck.property_checker(property_name="identity_id")
class UC03(MissingPropertyCheck["Credential"]):
    ...


@CredentialCheck.property_checker(property_name="identity_username")
class UC04(MissingPropertyCheck["Credential"]):
    ...


@CredentialCheck.property_checker(property_name="username")
class UC05(PropertyConstraintCheck["Credential"]):
    constraint_name = "guest collection local account exists"

    def value_is_ok(self, value: "Credential") -> bool:
        ok = True
        if value.username:
            try:
                pwd.getpwnam(value.username)
            except KeyError:
                ok = False
        return ok
