import uuid

import click
from gcs_migration.models import MigrationPlan
from .decorators import requires_migration_plan


@click.command(
    "disable-guest-collection",
    short_help="Mark a guest collection to ignore during migration",
    help="""\
This command disables a guest collection from migration. This can be used
to eliminate guest collections which are no longer valid because the shared
path or local user no longer exists.
""",
)
@requires_migration_plan
@click.argument("COLLECTION_ID", type=click.types.UUIDParameterType())
def disable_guest_collection(
    collection_id: uuid.UUID, migration_plan: MigrationPlan
) -> None:
    gc = migration_plan.get_guest_collection_by_id(collection_id)
    if not gc:
        raise click.ClickException(f"Guest collection {collection_id} does not exist")
    gc.disable = True
    migration_plan.dump_guest_collections()
