from typing import Optional, TYPE_CHECKING
import uuid

import click

from ..models import MigrationPlan
from .decorators import requires_migration_plan

if TYPE_CHECKING:
    from ..typing.gcs_documents import IdentityMappingDict  # noqa: F401


@click.command(
    "load-sharing-state", help="Load sharing state file for a guest collection"
)
@click.argument("COLLECTION_ID", required=False, type=click.types.UUIDParameterType())
@requires_migration_plan
def load_sharing_state(
    collection_id: Optional[uuid.UUID], migration_plan: MigrationPlan
) -> None:
    if collection_id:
        gc = migration_plan.get_guest_collection_by_id(collection_id)
        if not gc:
            raise click.ClickException("Unknown collection {collection_id}")
        if gc.disable:
            raise click.ClickException("Collection {collection_id} is disabled")
        gc.load_share_state_file()

        if gc.base_path is None:
            raise click.ClickException(
                f"Unable to load collection path for {gc.id} from {gc.share_state_file}"
            )
        migration_plan.dump_guest_collection(str(collection_id))
    elif migration_plan.guest_collections:
        errs = []
        for gc in migration_plan.guest_collections:
            if not gc.disable:
                gc.load_share_state_file()
                if gc.base_path is None:
                    errs.append(
                        f"Unable to load collection path for {gc.id} from {gc.share_state_file}"
                    )
        if errs:
            raise click.ClickException("\n".join(errs))
        migration_plan.dump_guest_collections()
