import datetime
import json
import os
import pathlib
from typing import Optional
from zipfile import ZipFile, ZIP_BZIP2, ZIP_STORED

import click

from ..version import __version__
from gcs_migration.models import MigrationPlan
from .decorators import requires_migration_plan


@click.command("create")
@click.version_option(version=__version__)
@click.option(
    "--description",
    "-d",
    metavar="DESCRIPTION",
    help="Text description of the snapshot",
)
@requires_migration_plan
def snapshot_create(description: Optional[str], migration_plan: MigrationPlan) -> None:
    snapshot_dir = pathlib.Path("./migration_snapshots")
    if not snapshot_dir.exists():
        os.makedirs(snapshot_dir, mode=0o700)

    snapshot_number = 1

    for fn in os.listdir(snapshot_dir):
        try:
            idx = int(fn)
            if idx >= snapshot_number:
                snapshot_number = idx + 1
        except ValueError:
            pass

    dt = datetime.datetime.now()
    dt = dt - datetime.timedelta(microseconds=dt.microsecond)

    metadata = {"timestamp": str(dt)}
    if description:
        metadata["description"] = description

    with ZipFile(
        snapshot_dir / f"{snapshot_number:04}", mode="w", compression=ZIP_BZIP2
    ) as z:
        z.writestr("metadata.json", json.dumps(metadata), ZIP_STORED)
        for root, _dirs, files in os.walk("migration_plan"):
            for fn in files:
                z.write(pathlib.Path(root) / fn)
    click.echo(f"Created snapshot {snapshot_number}")
