import re
from typing import Optional

from ..typing.gcs_documents import PathRestrictionsDict


def parse_restrict_paths(
    restrict_paths: Optional[str],
) -> Optional[PathRestrictionsDict]:
    read = []
    read_write = []
    none = []

    if not restrict_paths:
        return None

    for restriction in re.split(r"(?<!\\),", restrict_paths):
        m = re.match("^(R|RW|N)([/$~].*)", restriction, flags=re.I)
        if not m:
            raise Exception("Bad Path Restriction: {}".format(restriction))

        if m.group(1).upper() == "R":
            read.append(m.group(2))
        elif m.group(1).upper() == "RW":
            read_write.append(m.group(2))
        elif m.group(1).upper() == "N":
            none.append(m.group(2))
        else:
            raise Exception("Bad Path Restriction: {}".format(restriction))

    return {
        "DATA_TYPE": "path_restrictions#1.0.0",
        "read": read,
        "read_write": read_write,
        "none": none,
    }
