import marshmallow as ma
from marshmallow_oneofschema import OneOfSchema

from ..api.endpoint import EndpointSchema
from ..api.schema_version_checker import version_safe_type_schemas
from ..api.domain import domain_private_schema
from .oidc_server import oidc_server_schema
from .oidc_registration import oidc_registration_schema


class EndpointConfig_1_0_0_Schema(EndpointSchema):
    _DATA_TYPE = "endpoint_config#1.0.0"

    DATA_TYPE = ma.fields.String(
        required=True,
        allow_none=False,
        default="endpoint_config#1.1.0",
        validate=[ma.validate.Equal(_DATA_TYPE)],
    )

    # enable sequential random-looking domains
    domain_index = ma.fields.Int()

    oauth_state_key = ma.fields.Str(
        doc="Secret to encode and decode the OAuth state variable"
    )

    # fingerprint used as gcs_private_version_json
    fingerprint = ma.fields.Raw(required=False)


class EndpointConfig_1_1_0_Schema(EndpointConfig_1_0_0_Schema):
    _DATA_TYPE = "endpoint_config#1.1.0"

    DATA_TYPE = ma.fields.String(
        required=True,
        allow_none=False,
        default="endpoint_config#1.1.0",
        validate=[ma.validate.Equal(_DATA_TYPE)],
    )

    oidc_server = ma.fields.Nested(oidc_server_schema, required=False, allow_none=True)

    domain = ma.fields.Nested(domain_private_schema, required=False, allow_none=True)


class EndpointConfig_1_2_0_Schema(EndpointConfig_1_1_0_Schema):
    _DATA_TYPE = "endpoint_config#1.2.0"

    DATA_TYPE = ma.fields.String(
        required=True,
        allow_none=False,
        default="endpoint_config#1.2.0",
        validate=[ma.validate.Equal(_DATA_TYPE)],
    )

    oidc_registration = ma.fields.Nested(
        oidc_registration_schema, required=False, allow_none=True
    )


endpoint_config_1_0_0_schema = EndpointConfig_1_0_0_Schema()
endpoint_config_1_1_0_schema = EndpointConfig_1_1_0_Schema()
endpoint_config_1_2_0_schema = EndpointConfig_1_2_0_Schema()


class EndpointConfigSchema(OneOfSchema):
    _DATA_TYPE = endpoint_config_1_2_0_schema._DATA_TYPE
    type_field = "DATA_TYPE"
    type_schemas = version_safe_type_schemas(
        {
            "endpoint_config#1.0.0": endpoint_config_1_0_0_schema,
            "endpoint_config#1.1.0": endpoint_config_1_1_0_schema,
            "endpoint_config#1.2.0": endpoint_config_1_2_0_schema,
        }
    )
    type_field_remove = False

    def get_obj_type(self, obj):
        return self._DATA_TYPE


endpoint_config_schema = EndpointConfigSchema()
