"""
globus-connect-server endpoint migrate-uuid
"""
import json
import os
import pwd

import click
from gcs_cli.parsing.command_decorator import globus_command

from globus.manager.api.blueprints.utils import update_object
import globus.manager.api.models as models
from globus.manager.utils.keychain import NodeKey

from globus.manager.api.app import make_app


@globus_command(
    "migrate-uuid",
    short_help="Update the uuid of an endpoint migrated from v5.3",
    help="Update the uuid of an endpoint migrated from v5.3",
    disable_options=["format", "explicit_host"],
    hidden=True,
)
def endpoint_migrate_uuid() -> None:
    app = make_app(app_config="globus.manager.api.config.migrate_uuid")
    models.db.init_app(app)

    pwent = pwd.getpwnam("gcsweb")

    if os.getuid() not in [0, pwent.pw_uid]:
        click.echo(
            "This command must be run using the root or gcsweb account.", err=True
        )
        click.get_current_context().exit(1)

    with app.app_context():
        models.db.create_all()
        models.db.session.commit()

        globus_node_key = NodeKey(
            **json.loads(
                models.Configuration.query.filter_by(name="node_key").one().value
            )
        )

        for conf in models.Configuration.query:
            app.config[conf.name.upper()] = conf.value

        app.config["NODE_KEY"] = globus_node_key

        items = app.appsync_client.query_all(id="KEY_CHAIN")
        for item in items:
            app.appsync_client.process_item(item)

        items = app.appsync_client.query_all(id="ENDPOINT")
        for item in items:
            app.appsync_client.process_item(item)

        endpoint = models.Endpoint.query.one()

        update_object(endpoint, models.Endpoint.migrate_endpoint_uuid)
