"""Remove connector table

Revision ID: b85b3712bcd9
Revises: f850f76ca18c
Create Date: 2019-12-16 14:55:47.961827

"""
from datetime import datetime
from alembic import op
import sqlalchemy as sa
import sqlalchemy_json


# revision identifiers, used by Alembic.
revision = 'b85b3712bcd9'
down_revision = 'f850f76ca18c'
branch_labels = None
depends_on = None


def upgrade():
    op.execute('PRAGMA foreign_keys = OFF')
    op.execute("PRAGMA legacy_alter_table=ON")
    # Remove foreign key to connectors table
    op.rename_table("storage_gateway", "storage_gateway_old")
    op.create_table(
        'storage_gateway',
        sa.Column('id', sa.TEXT(),
            nullable=False),
        sa.Column(
            'display_name',
            sa.TEXT(),
            nullable=False),
        sa.Column(
            'credential',
            sqlalchemy_json.NestedMutableJson(),
            nullable=True),
        sa.Column(
            'storage_policies',
            sqlalchemy_json.NestedMutableJson(),
            nullable=True),
        sa.Column(
            'allow_guest_collections',
            sa.BOOLEAN(),
            server_default='0',
            nullable=False),
        sa.Column(
            'allow_mapped_collections',
            sa.BOOLEAN(),
            server_default='0',
            nullable=False),
        sa.Column(
            'require_high_assurance',
            sa.BOOLEAN(),
            server_default='0',
            nullable=False),
        sa.Column(
            'connector_id',
            sa.TEXT(),
            nullable=False),
        sa.ForeignKeyConstraint(
            ['id'],
            ['configuration_object.id'],),
        sa.PrimaryKeyConstraint('id'),
        sa.UniqueConstraint('display_name')
    )
    op.execute(
        """
        INSERT INTO storage_gateway
        (id, display_name, credential, storage_policies,
        allow_guest_collections, allow_mapped_collections,
        require_high_assurance, connector_id)
        SELECT id, display_name, credential, storage_policies,
        allow_guest_collections, allow_mapped_collections,
        require_high_assurance, connector_id
        FROM storage_gateway_old
        """)
    # Remove the backup
    op.drop_table('storage_gateway_old')
    op.drop_table('connector')


def downgrade():
    op.execute('PRAGMA foreign_keys = OFF')
    op.execute("PRAGMA legacy_alter_table=ON")
    op.create_table(
        'connector',
        sa.Column('created_at', sa.DateTime(), nullable=False),
        sa.Column('updated_at', sa.DateTime(), nullable=False),
        sa.Column('id', sa.TEXT(),
            nullable=False),
        sa.Column(
            'display_name',
            sa.TEXT(),
            nullable=False),
        sa.Column(
            'enabled',
            sa.BOOLEAN(),
            server_default='0',
            nullable=False),
        sa.Column(
            'allow_mapped_collections',
            sa.BOOLEAN(),
            nullable=False,
            server_default='0'),
        sa.PrimaryKeyConstraint('id'),
        sa.UniqueConstraint('display_name')
    )

    CONNECTORS = [
        dict(
            id='7e3f3f5e-350c-4717-891a-2f451c24b0d4',
            display_name='SpectraLogic BlackPearl',
            enabled=True,
            allow_mapped_collections=False),
        dict(
            id='7c100eae-40fe-11e9-95a3-9cb6d0d9fd63',
            display_name='Box',
            enabled=True,
            allow_mapped_collections=True),
        dict(
            id='1b6374b0-f6a4-4cf7-a26f-f262d9c6ca72',
            display_name='Ceph',
            enabled=True,
            allow_mapped_collections=True),
        dict(
            id='56366b96-ac98-11e9-abac-9cb6d0d9fd63',
            display_name='Google Cloud Storage',
            enabled=True,
            allow_mapped_collections=True),
        dict(
            id='976cf0cf-78c3-4aab-82d2-7c16adbcc281',
            display_name='Google Drive',
            enabled=True,
            allow_mapped_collections=True),
        dict(
            id='145812c8-decc-41f1-83cf-bb2a85a2a70b',
            display_name='POSIX',
            enabled=True,
            allow_mapped_collections=True),
        dict(
            id='7643e831-5f6c-4b47-a07f-8ee90f401d23',
            display_name='S3',
            enabled=True,
            allow_mapped_collections=False),
        dict(
            id='fb656a17-0f69-4e59-95ff-d0a62ca7bdf5',
            display_name='HPSS',
            enabled=False,
            allow_mapped_collections=False,
        ),
        dict(
            id='ba09188f-802a-4bed-820f-6d2e222b9323',
            display_name='HDFS',
            enabled=False,
            allow_mapped_collections=False,
        ),
        dict(
            id='73651282-d5a5-4121-93c7-eb4682948329',
            display_name='iRODS',
            enabled=False,
            allow_mapped_collections=False,
        ),
    ]

    conn = op.get_bind()
    sql = sa.text(
        'insert into connector(id, display_name, enabled, '
        'allow_mapped_collections, created_at, updated_at) '
        'values(:id, :display_name, :enabled, :allow_mapped_collections,'
        ':now, :now)')
    for st in CONNECTORS:
        conn.execute(sql,
                     id=st['id'],
                     display_name=st['display_name'],
                     enabled=st['enabled'],
                     allow_mapped_collections=st['allow_mapped_collections'],
                     now=str(datetime.utcnow()))
