"""Refactor guest to mapped collection relationship

Revision ID: f9ee46456dfe
Revises: 32a33d51c6d7
Create Date: 2020-02-07 01:50:51.401676

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'f9ee46456dfe'
down_revision = '32a33d51c6d7'
branch_labels = None
depends_on = None


def upgrade():
    op.execute('PRAGMA foreign_keys = OFF')
    op.execute("PRAGMA legacy_alter_table=ON")

    conn = op.get_bind()

    op.drop_table('collection')
    op.drop_table('storage_gateway')
    op.create_table(
        'collection',
        sa.Column('id', sa.TEXT(), nullable=False),
        sa.Column('domain', sa.TEXT(), nullable=False, unique=True),
        sa.Column('user_credential_id', sa.TEXT(), nullable=True),
        sa.Column('storage_gateway_id', sa.TEXT(), nullable=False),
        sa.Column(
            'allow_guest_collections',
             sa.BOOLEAN(),
             server_default='0',
             nullable=False),
        sa.Column(
            'collection_type',
            sa.Enum('mapped', 'guest',
                name='collectiontype'),
            nullable=False),
        sa.ForeignKeyConstraint(
            ['id'],
            ['configuration_object.id'],
            name='col_id'),
        sa.ForeignKeyConstraint(
            ['storage_gateway_id'],
            ['storage_gateway.id'], ),
        sa.ForeignKeyConstraint(
            ['user_credential_id'],
            ['user_credential.id'], ),
        sa.PrimaryKeyConstraint('id')
    )
    op.create_table(
        'storage_gateway',
        sa.Column('id', sa.TEXT(),
            nullable=False),
        sa.Column(
            'display_name',
            sa.TEXT(),
            nullable=False),
        sa.Column(
            'require_high_assurance',
            sa.BOOLEAN(),
            server_default='0',
            nullable=False),
        sa.Column(
            'connector_id',
            sa.TEXT(),
            nullable=False),
        sa.ForeignKeyConstraint(
            ['id'],
            ['configuration_object.id'],),
        sa.PrimaryKeyConstraint('id'),
        sa.UniqueConstraint('display_name')
    )


def downgrade():
    raise RuntimeError("downgrade migration not implemented")
